use std::{cell::RefCell, rc::Rc};

use crate::error_template::{AppError, ErrorTemplate};
use leptos::*;
use leptos_meta::*;
use leptos_router::*;

#[component]
pub fn App() -> impl IntoView {
    // Provides context that manages stylesheets, titles, meta tags, etc.
    provide_meta_context();

    view! {


        // injects a stylesheet into the document <head>
        // id=leptos means cargo-leptos will hot-reload this stylesheet
        // Stylesheet name is the CRATE NAME by default!!!
        <Stylesheet id="leptos" href="/pkg/share-web.css"/>

        // sets the document title
        <Title text="Welcome to Leptos"/>

        // content for this welcome page
        <Router fallback=|| {
            let mut outside_errors = Errors::default();
            outside_errors.insert_with_default_key(AppError::NotFound);
            view! {
                <ErrorTemplate outside_errors/>
            }
            .into_view()
        }>
            <main>
                <Routes>
                    <Route path="" view=HomePage/>
                    <Route path="/new" view=NewPage/>
                    <Route path="/game" view=Game/>
                    <Route path="/lobby" view=Lobby/>
                </Routes>
            </main>
        </Router>
    }
}

/// Renders the home page of your application.
#[component]
fn HomePage() -> impl IntoView {

    view! {
        <Title text="isdom"/>
        <main>
        <div class="py-8 px-8 mx-auto max-w-screen-xl text-center lg:py-16 lg:px-12">
        <a href="#" class="inline-flex justify-between items-center py-1 px-1 pr-4 mb-7 text-sm text-gray-700 bg-gray-100 rounded-full dark:bg-gray-800 dark:text-white hover:bg-gray-200 dark:hover:bg-gray-700" role="alert">
            <span class="text-xs bg-primary-600 rounded-full text-grey px-4 py-1.5 mr-3">New</span> <span class="text-sm font-medium">Wisdom-Version 0.1 </span> 
        </a>
        <h1 class="mb-4 text-4xl font-extrabold tracking-tight leading-none text-gray-900 md:text-5xl lg:text-6xl dark:text-white">Collecting wisdom, sharing thoughts</h1>
        <p class="mb-8 text-lg font-normal text-gray-500 lg:text-xl sm:px-16 xl:px-48 dark:text-gray-400">Here you can collect, create and spread wisdom - share inspiration together</p>
        <div class="flex flex-col mb-8 lg:mb-16 space-y-4 sm:flex-row sm:justify-center sm:space-y-0 sm:space-x-4">
            <a href="/new" class="inline-flex justify-center items-center py-3 px-5 text-base font-medium text-center text-grey rounded-lg bg-primary-700 hover:bg-primary-800 focus:ring-4 focus:ring-primary-300 dark:focus:ring-primary-900">
                Start now
                <svg class="ml-2 -mr-1 w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M10.293 3.293a1 1 0 011.414 0l6 6a1 1 0 010 1.414l-6 6a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-4.293-4.293a1 1 0 010-1.414z" clip-rule="evenodd"></path></svg>
            </a>
            <a href="#" class="inline-flex justify-center items-center py-3 px-5 text-base font-medium text-center text-gray-900 rounded-lg border border-gray-300 hover:bg-gray-100 focus:ring-4 focus:ring-gray-100 dark:text-white dark:border-gray-700 dark:hover:bg-gray-700 dark:focus:ring-gray-800">
                <svg class="mr-2 -ml-1 w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 6a2 2 0 012-2h6a2 2 0 012 2v8a2 2 0 01-2 2H4a2 2 0 01-2-2V6zM14.553 7.106A1 1 0 0014 8v4a1 1 0 00.553.894l2 1A1 1 0 0018 13V7a1 1 0 00-1.447-.894l-2 1z"></path></svg>
                Watch video
            </a>  
        </div>
       
    </div>
    <Work/>
    <Workstart/>
    <Footer/>
        </main>
        <Bar/> 
       
    }
}

/// Renders the home page of your application.
#[component]
fn bar() -> impl IntoView {

    view! {
        

<div class="fixed z-50 w-full h-16 max-w-lg -translate-x-1/2 bg-white border border-gray-200 rounded-full left-1/2 dark:bg-gray-700 dark:border-gray-600">
<div class="grid h-full max-w-lg grid-cols-5 mx-auto">
    <button data-tooltip-target="tooltip-home" type="button" class="inline-flex flex-col items-center justify-center px-5 rounded-s-full hover:bg-gray-50 dark:hover:bg-gray-800 group">
        <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
            <path d="m19.707 9.293-2-2-7-7a1 1 0 0 0-1.414 0l-7 7-2 2a1 1 0 0 0 1.414 1.414L2 10.414V18a2 2 0 0 0 2 2h3a1 1 0 0 0 1-1v-4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v4a1 1 0 0 0 1 1h3a2 2 0 0 0 2-2v-7.586l.293.293a1 1 0 0 0 1.414-1.414Z"/>
        </svg>
        <span class="sr-only">Home</span>
    </button>
    <div id="tooltip-home" role="tooltip" class="absolute z-10 invisible inline-block px-3 py-2 text-sm font-medium text-white transition-opacity duration-300 bg-gray-900 rounded-lg shadow-sm opacity-0 tooltip dark:bg-gray-700">
        Home
        <div class="tooltip-arrow" data-popper-arrow></div>
    </div>
    <button data-tooltip-target="tooltip-wallet" type="button" class="inline-flex flex-col items-center justify-center px-5 hover:bg-gray-50 dark:hover:bg-gray-800 group">
        <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
            <path d="M11.074 4 8.442.408A.95.95 0 0 0 7.014.254L2.926 4h8.148ZM9 13v-1a4 4 0 0 1 4-4h6V6a1 1 0 0 0-1-1H1a1 1 0 0 0-1 1v13a1 1 0 0 0 1 1h17a1 1 0 0 0 1-1v-2h-6a4 4 0 0 1-4-4Z"/>
            <path d="M19 10h-6a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h6a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1Zm-4.5 3.5a1 1 0 1 1 0-2 1 1 0 0 1 0 2ZM12.62 4h2.78L12.539.41a1.086 1.086 0 1 0-1.7 1.352L12.62 4Z"/>
        </svg>
        <span class="sr-only">Wallet</span>
    </button>
    <div id="tooltip-wallet" role="tooltip" class="absolute z-10 invisible inline-block px-3 py-2 text-sm font-medium text-white transition-opacity duration-300 bg-gray-900 rounded-lg shadow-sm opacity-0 tooltip dark:bg-gray-700">
        Wallet
        <div class="tooltip-arrow" data-popper-arrow></div>
    </div>
    <div class="flex items-center justify-center">
        <button data-tooltip-target="tooltip-new" type="button" class="inline-flex items-center justify-center w-10 h-10 font-medium bg-blue-600 rounded-full hover:bg-blue-700 group focus:ring-4 focus:ring-blue-300 focus:outline-none dark:focus:ring-blue-800">
            <svg class="w-4 h-4 text-white" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 18 18">
                <path stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9 1v16M1 9h16"/>
            </svg>
            <span class="sr-only">New item</span>
        </button>
    </div>
    <div id="tooltip-new" role="tooltip" class="absolute z-10 invisible inline-block px-3 py-2 text-sm font-medium text-white transition-opacity duration-300 bg-gray-900 rounded-lg shadow-sm opacity-0 tooltip dark:bg-gray-700">
        Create new item
        <div class="tooltip-arrow" data-popper-arrow></div>
    </div>
    <button data-tooltip-target="tooltip-settings" type="button" class="inline-flex flex-col items-center justify-center px-5 hover:bg-gray-50 dark:hover:bg-gray-800 group">
        <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 20 20">
            <path stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 12.25V1m0 11.25a2.25 2.25 0 0 0 0 4.5m0-4.5a2.25 2.25 0 0 1 0 4.5M4 19v-2.25m6-13.5V1m0 2.25a2.25 2.25 0 0 0 0 4.5m0-4.5a2.25 2.25 0 0 1 0 4.5M10 19V7.75m6 4.5V1m0 11.25a2.25 2.25 0 1 0 0 4.5 2.25 2.25 0 0 0 0-4.5ZM16 19v-2"/>
        </svg>
        <span class="sr-only">Settings</span>
    </button>
    <div id="tooltip-settings" role="tooltip" class="absolute z-10 invisible inline-block px-3 py-2 text-sm font-medium text-white transition-opacity duration-300 bg-gray-900 rounded-lg shadow-sm opacity-0 tooltip dark:bg-gray-700">
        Settings
        <div class="tooltip-arrow" data-popper-arrow></div>
    </div>
    <button data-tooltip-target="tooltip-profile" type="button" class="inline-flex flex-col items-center justify-center px-5 rounded-e-full hover:bg-gray-50 dark:hover:bg-gray-800 group">
        <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
            <path d="M10 0a10 10 0 1 0 10 10A10.011 10.011 0 0 0 10 0Zm0 5a3 3 0 1 1 0 6 3 3 0 0 1 0-6Zm0 13a8.949 8.949 0 0 1-4.951-1.488A3.987 3.987 0 0 1 9 13h2a3.987 3.987 0 0 1 3.951 3.512A8.949 8.949 0 0 1 10 18Z"/>
        </svg>
        <span class="sr-only">Profile</span>
    </button>
    <div id="tooltip-profile" role="tooltip" class="absolute z-10 invisible inline-block px-3 py-2 text-sm font-medium text-white transition-opacity duration-300 bg-gray-900 rounded-lg shadow-sm opacity-0 tooltip dark:bg-gray-700">
        Profile
        <div class="tooltip-arrow" data-popper-arrow></div>
    </div>
</div>
</div>
    }
}




/// Renders the home page of your application.
#[component]
fn work() -> impl IntoView {

    view! {
       
 <section class="bg-white dark:bg-gray-900">
    <div class="gap-8 items-center px-16  mx-auto max-w-screen-xl xl:gap-16 md:grid md:grid-cols-2  lg:px-6">
    <img class="w-0.2 dark:hidden" src="https://cdn-icons-png.flaticon.com/512/10777/10777094.png" alt="dashboard image" />
        <div class="mt-4 md:mt-0">
            <h2 class="mb-4 text-4xl tracking-tight font-extrabold text-gray-900 dark:text-white">Reflect and grow</h2>
            <p class="mb-6 font-light text-gray-500 md:text-lg dark:text-gray-400">Connecting with your friends and family as well as discovering new ones Collect and create wisdom to rise in rank. Compare yourself with your friends. Receive ratings from the whole world or just from your circle of friends is easy with features like Groups.</p>
            <a href="#" class="inline-flex items-center text-white bg-primary-700 hover:bg-primary-800 focus:ring-4 focus:ring-primary-300 font-medium rounded-lg text-sm px-5 py-2.5 text-center dark:focus:ring-primary-900">
                Get started
                <svg class="ml-2 -mr-1 w-5 h-5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M10.293 3.293a1 1 0 011.414 0l6 6a1 1 0 010 1.414l-6 6a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-4.293-4.293a1 1 0 010-1.414z" clip-rule="evenodd"></path></svg>
            </a>
        </div>
    </div>
</section>
    }
}

/// Renders the home page of your application.
#[component]
fn workstart() -> impl IntoView {

    view! {

<section class="bg-white mt-12">
 <div class="">
   <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1440 320" class="w-full h-auto">
     <path fill="rgb(59 130 246)" fill-opacity="1" d="M0,64L48,80C96,96,192,128,288,128C384,128,480,96,576,85.3C672,75,768,85,864,122.7C960,160,1056,224,1152,234.7C1248,245,1344,203,1392,181.3L1440,160L1440,320L1392,320C1344,320,1248,320,1152,320C1056,320,960,320,864,320C768,320,672,320,576,320C480,320,384,320,288,320C192,320,96,320,48,320L0,320Z"></path>
   </svg>
 </div>

 <div class="relative bg-blue-500  z-10 py-12 px-4 mx-auto max-w-screen-xl sm:py-16 lg:px-6">
   <div class="mx-auto max-w-screen-sm text-center">
     <h2 class="mb-4 text-4xl tracking-tight font-extrabold leading-tight text-white ">Start collecting now</h2>
     <p class="mb-6 font-light text-white md:text-lg">Start sharing and collecting wisdom. Become smarter.</p>
     <a href="/new" class="text-white bg-indigo-600 hover:bg-indigo-700 focus:ring-4 focus:ring-indigo-300 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2 focus:outline-none">Lets Go</a>
   </div>
 </div>


 <div class="relative overflow-hidden">
 <div class="absolute inset-x-0 top-0 h-1/2 bg-blue-500"></div>
 <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1440 320" class="relative z-10 w-full h-auto pb-28">
   <path fill="white" fill-opacity="1" d="M0,64L48,80C96,96,192,128,288,128C384,128,480,96,576,85.3C672,75,768,85,864,122.7C960,160,1056,224,1152,234.7C1248,245,1344,203,1392,181.3L1440,160L1440,320L1392,320C1344,320,1248,320,1152,320C1056,320,960,320,864,320C768,320,672,320,576,320C480,320,384,320,288,320C192,320,96,320,48,320L0,320Z"></path>
 </svg>
</div>

</section>


    }
}


/// Renders the home page of your application.
#[component]
fn footer() -> impl IntoView {

    view! {
       
        <footer class=" bg-white dark:bg-gray-800">
      
        <div class="mx-auto max-w-screen-xl text-center p-12">
            <a href="#" class="flex justify-center items-center text-2xl font-semibold text-gray-900 dark:text-white">
                Wisdom    
            </a>
            <p class="my-6 text-gray-500 dark:text-gray-400"> Opensource - Share and collecting wisdoms</p>
            <ul class="flex flex-wrap justify-center items-center mb-6 text-gray-900 dark:text-white">
                <li>
                    <a href="#" class="mr-4 hover:underline md:mr-6 ">About</a>
                </li>
                <li>
                    <a href="#" class="mr-4 hover:underline md:mr-6">Blog</a>
                </li>
                <li>
                    <a href="#" class="mr-4 hover:underline md:mr-6">FAQs</a>
                </li>
                <li>
                    <a href="#" class="mr-4 hover:underline md:mr-6">Github</a>
                </li>
            </ul>
            <span class="text-sm text-gray-500 sm:text-center dark:text-gray-400"> 2024-2026 <a href="#" class="hover:underline">Marcel Hurban </a>. All Rights Reserved.</span>
        </div>
      </footer>
    }
}


#[component]
pub fn NewPage() -> impl IntoView {
    view! {
        <section class="bg-white dark:bg-gray-900">
  <div class="py-8 px-4 mx-auto max-w-screen-xl lg:py-16 lg:px-6">
      <div class="mx-auto max-w-screen-md text-center mb-8 lg:mb-12">
          <h2 class="mb-4 text-4xl tracking-tight font-extrabold text-gray-900 dark:text-white">Choose your gamemode</h2>
          <p class="mb-5 font-light text-gray-500 sm:text-xl dark:text-gray-400"></p>
      </div>
      <div class="space-y-8 lg:grid lg:grid-cols-3 sm:gap-6 xl:gap-10 lg:space-y-0">
     
          <div class="flex flex-col p-6 mx-auto max-w-lg text-center text-gray-900 bg-white rounded-lg border border-gray-100 shadow dark:border-gray-600 xl:p-8 dark:bg-gray-800 dark:text-white">
              <h3 class="mb-4 text-2xl font-semibold">Worldwide</h3>
              <p class="font-light text-gray-500 sm:text-lg dark:text-gray-400">Create or collect wisdoms worldwide.</p>
           
             
              <a href="/game" class="text-white bg-primary-600 border-solid border-2 bg-indigo-600 hover:bg-indigo-700 hover:bg-primary-700 focus:ring-4 focus:ring-primary-200 font-medium rounded-lg text-sm px-5 py-2.5 text-center dark:text-white  dark:focus:ring-primary-900 my-12">Play</a>
          </div>
       
          <div class="flex flex-col p-6 mx-auto max-w-lg text-center text-gray-900 bg-white rounded-lg border border-gray-100 shadow dark:border-gray-600 xl:p-8 dark:bg-gray-800 dark:text-white">
              <h3 class="mb-4 text-2xl font-semibold">Private</h3>
              <p class="font-light text-gray-500 sm:text-lg dark:text-gray-400">Enter the invitation code or group code and share your wisdom or collect some from the group</p>
            
                <form class="max-w-sm mx-auto">
        
                <div class="relative">
                <div class="absolute inset-y-0 start-0 flex items-center ps-3.5 pointer-events-none">
                    <svg class="w-4 h-4 text-gray-500 dark:text-gray-400" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 16">
                    <path d="m10.036 8.278 9.258-7.79A1.979 1.979 0 0 0 18 0H2A1.987 1.987 0 0 0 .641.541l9.395 7.737Z"/>
                    <path d="M11.241 9.817c-.36.275-.801.425-1.255.427-.428 0-.845-.138-1.187-.395L0 2.6V14a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V2.5l-8.759 7.317Z"/>
                    </svg>
                </div>
                <input type="text" id="email-address-icon" class="bg-gray-50 border border-gray-300 text-gray-900 text-sm rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full ps-10 p-2.5  dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500 my-8" placeholder="invitation code"/>
                </div>
                </form>

              <a href="#" class="text-white border-solid border-2 bg-primary-600 bg-indigo-600 hover:bg-indigo-700 hover:bg-primary-700 focus:ring-4 focus:ring-primary-200 font-medium rounded-lg text-sm px-5 py-2.5 text-center dark:text-white  dark:focus:ring-primary-900 my-2 ">Play</a>
          </div>
      </div>
  </div>
</section>

<Footer/>
    }
}




#[component]
pub fn game() -> impl IntoView {
    view! {
 
<CardStack/>
<Gamenavigation />
    }
}



/// Renders the Gamecard
#[component]
fn gamenavigation() -> impl IntoView {
    // You'll need to implement these signals in your actual code
    let (countdown, set_countdown) = create_signal(60); // Beispiel: 60 Sekunden Countdown
    let (participants, set_participants) = create_signal(5); // Beispiel: 5 Teilnehmer
    let (current_round, set_current_round) = create_signal(2); // Beispiel: Runde 2

    view! {
        <div class="fixed z-50 w-full h-16 max-w-lg -translate-x-1/2 bg-white border border-gray-200 rounded-full bottom-4 left-1/2 dark:bg-gray-700 dark:border-gray-600">
            <div class="flex h-full max-w-lg mx-auto items-center justify-center">
                <button type="button" class="inline-flex flex-col items-center justify-center px-5 rounded-s-full hover:bg-gray-50 dark:hover:bg-gray-800 group">
                    <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                        <path d="M9 0a9 9 0 1 0 0 18A9 9 0 0 0 9 0zm0 16a7 7 0 1 1 0-14 7 7 0 0 1 0 14zm1-8h3v2h-3v3H8v-3H5V8h3V5h2v3z"/>
                    </svg>
                    <span class="text-xs mt-1">{move || format!("{} Players", participants.get())}</span>
                </button>

                <button type="button" class="inline-flex items-center justify-center w-10 h-10 font-medium bg-blue-600 rounded-full hover:bg-blue-700 group focus:ring-4 focus:ring-blue-300 focus:outline-none dark:focus:ring-blue-800 mx-4">
                    <span class="text-white text-sm font-bold">{move || countdown.get()}</span>
                </button>

                <button type="button" class="inline-flex flex-col items-center justify-center px-5 hover:bg-gray-50 dark:hover:bg-gray-800 group">
                    <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                        <path d="M10 0a10 10 0 1 0 10 10A10.011 10.011 0 0 0 10 0Zm3.982 13.982a6.938 6.938 0 0 1-7.964 0A3.997 3.997 0 0 1 10 11a3.997 3.997 0 0 1 3.982 2.982ZM13.5 5.5a3.5 3.5 0 1 1-7 0 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5"/>
                    </svg>
                    <span class="text-xs mt-1">{move || format!("Round {}", current_round.get())}</span>
                </button>
            </div>
        </div>
    }
}



#[component]
pub fn CardStack() -> impl IntoView {
    let cards = vec![
        ("1", "Weisheit beginnt mit Verwunderung.", "- Sokrates"),
        ("2", "Der Weg ist das Ziel.", "- Konfuzius"),
        ("3", "Ich weiß, dass ich nichts weiß.", "- Sokrates"),
        // Fügen Sie hier weitere Karten hinzu
    ];

    let cards_state = Rc::new(RefCell::new(cards));
    let current_card = create_rw_signal(None);
    let drag_start = create_rw_signal(0.0);
    let is_dragging = create_rw_signal(false);

    let draw_card = move |_| {
        let mut cards = cards_state.borrow_mut();
        if let Some(card) = cards.pop() {
            current_card.set(Some(card));
        }
    };

    let on_drag_start = move |e: web_sys::MouseEvent| {
        drag_start.set(e.client_y() as f64);
        is_dragging.set(true);
    };

    let on_drag_end = move |e: web_sys::MouseEvent| {
        if is_dragging.get() {
            let drag_end = e.client_y() as f64;
            let drag_distance = drag_start.get() - drag_end;
            if drag_distance > 50.0 {
                draw_card(());
            }
            is_dragging.set(false);
        }
    };

    view! {
        <div class="flex flex-col items-center justify-center min-h-screen bg-gray-100">
            <div 
                class="relative w-64 h-96 perspective-1000 cursor-grab"
                on:mousedown=on_drag_start
                on:mouseup=on_drag_end
                on:mouseleave=move |_| is_dragging.set(false)
            >
                {move || {
                    current_card.get().map(|card| view! {
                        <FlipCard number=card.0 quote=card.1 author=card.2 />
                    })
                }}
                <div class="absolute top-0 left-0 w-64 h-96 bg-white rounded-xl shadow-2xl transform rotate-3 transition-transform duration-300 -z-10">
                <div class="w-full h-full border-8 border-blue-400 rounded-xl p-4 flex flex-col justify-between">
                <div class="text-center font-serif italic text-lg px-2">
                "draw a card from the deck."
                <div class="mt-2 text-sm font-sans">Guide</div>
                 </div>
                </div>
                </div>
                <div class="absolute top-1 left-1 w-64 h-96 bg-white rounded-xl shadow-2xl transform rotate-3 transition-transform duration-300 -z-20"></div>
                <div class="absolute top-2 left-2 w-64 h-96 bg-white rounded-xl shadow-2xl transform rotate-3 transition-transform duration-300 -z-30"></div>
            </div>
        </div>
    }
}

use rand::Rng;
use leptos::*;
use web_sys::KeyboardEvent;

#[component]
pub fn FlipCard(
    number: &'static str,
    quote: &'static str,
    author: &'static str,
) -> impl IntoView {
    let words: Vec<&str> = quote.split_whitespace().collect();
    
    let mut rng = rand::thread_rng();
    let removed_index = rng.gen_range(0..words.len());
    let removed_word = words[removed_index];

    let (user_input, set_user_input) = create_signal(String::new());
    let (is_correct, set_is_correct) = create_signal(None::<bool>);

    let check_answer = move || {
        let correct = user_input.get().trim().to_lowercase() == removed_word.to_lowercase();
        set_is_correct.set(Some(correct));
    };

    let handle_keydown = move |ev: KeyboardEvent| {
        if ev.key() == "Enter" {
            check_answer();
        }
    };

    view! {
        <div class="w-64 h-96">
            <div class="w-64 h-96 bg-white rounded-xl shadow-2xl transform rotate-3 transition-transform duration-300 overflow-hidden">
                <div class="w-full h-full border-8 border-blue-400 rounded-xl p-4 flex flex-col justify-between">
                    <div class="text-2xl font-bold text-red-600">{number}</div>
                    <div class="text-center font-serif italic text-lg px-2">
                        {words.iter().enumerate().map(|(i, &word)| {
                            let element = if i == removed_index {
                                view! {
                                    <input
                                        type="text"
                                        placeholder="____"
                                        class=move || {
                                            let base_class = "w-20 text-center border-b border-gray-300 focus:outline-none focus:border-blue-500";
                                            match is_correct.get() {
                                                Some(true) => format!("{} text-green-500", base_class),
                                                Some(false) => format!("{} text-red-500", base_class),
                                                None => base_class.to_string(),
                                            }
                                        }
                                        on:input=move |ev| {
                                            set_user_input.set(event_target_value(&ev));
                                            set_is_correct.set(None);
                                        }
                                        on:keydown=handle_keydown
                                    />
                                }.into_view()
                            } else {
                                view! { <span>{word}</span> }.into_view()
                            };
                            
                            view! {
                                <>
                                    {element}
                                    {if i < words.len() - 1 { " " } else { "" }}
                                </>
                            }.into_view()
                        }).collect::<Vec<_>>()}
                        <div class="mt-2 text-sm font-sans">{author}</div>
                    </div>
                    <div class="text-2xl font-bold text-red-600 self-end transform rotate-180">{number}</div>
                </div>
            </div>
        </div> 
    }
}

#[component]
pub fn lobby() -> impl IntoView {
    view! {
 
<Lobbyinfo />
<LobbyGame/>

    }
}


#[component]
pub fn lobby_game() -> impl IntoView {
    view! {
        <div class="flex flex-col items-center justify-center min-h-screen bg-gray-100">
        <div class="w-64 h-96">
        <div class="w-64 h-96 bg-white rounded-xl shadow-2xl transform rotate-3 transition-transform duration-300 overflow-hidden">
            <div class="w-full h-full border-8 border-blue-400 rounded-xl p-4 flex flex-col justify-between">
            <table class="px-64 text-sm text-left rtl:text-right text-gray-500 dark:text-gray-400">
            <thead class="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
                <tr>
                    <th scope="col" class="px-6 py-3">
                        Player
                    </th>
                    <th scope="col" class="px-6 py-3">
                        <span class="sr-only">Edit</span>
                    </th>
                </tr>
            </thead>
            <tbody>
                <tr class="bg-white dark:bg-gray-800 hover:bg-gray-50 dark:hover:bg-gray-600">
                    <th scope="row" class="px-6 py-4 font-medium text-gray-900 whitespace-nowrap dark:text-white">
                        Player_1
                    </th>
                        
                    <td class="px-6 py-4 text-right">
                        <a href="#" class="font-medium text-blue-600 dark:text-blue-500 hover:underline">Edit</a>
                    </td>
                </tr>
            </tbody>
        </table>
                <div class="text-center font-serif italic text-lg px-2">
                    <div class="mt-2 text-sm font-sans"></div>
                </div>
                <div class="text-2xl font-bold text-red-600 self-end transform rotate-180"></div>
            </div>
        </div>
    </div> 
    </div> 


    }
}




/// Renders the Gamecard
#[component]
fn lobbyinfo() -> impl IntoView {

    let (participants, set_participants) = create_signal(5); // Beispiel: 5 Teilnehmer
    let (current_round, set_current_round) = create_signal(2); // Beispiel: Runde 2

    view! {
        <div class="fixed z-50 w-full h-16 max-w-lg -translate-x-1/2 bg-white border border-gray-200 rounded-full bottom-4 left-1/2 dark:bg-gray-700 dark:border-gray-600">
            <div class="flex h-full max-w-lg mx-auto items-center justify-center">
                <button type="button" class="inline-flex flex-col items-center justify-center px-5 rounded-s-full hover:bg-gray-50 dark:hover:bg-gray-800 group">
                    <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                        <path d="M9 0a9 9 0 1 0 0 18A9 9 0 0 0 9 0zm0 16a7 7 0 1 1 0-14 7 7 0 0 1 0 14zm1-8h3v2h-3v3H8v-3H5V8h3V5h2v3z"/>
                    </svg>
                    <span class="text-xs mt-1">{move || format!("{} Players", participants.get())}</span>
                </button>

                <button type="button" class="inline-flex items-center justify-center w-10 h-10 font-medium bg-blue-600 rounded-full hover:bg-blue-700 group focus:ring-4 focus:ring-blue-300 focus:outline-none dark:focus:ring-blue-800 mx-4">
                    <span class="text-white text-sm font-bold">GO</span>
                </button>

                <button type="button" class="inline-flex flex-col items-center justify-center px-5 hover:bg-gray-50 dark:hover:bg-gray-800 group">
                    <svg class="w-5 h-5 mb-1 text-gray-500 dark:text-gray-400 group-hover:text-blue-600 dark:group-hover:text-blue-500" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="currentColor" viewBox="0 0 20 20">
                        <path d="M10 0a10 10 0 1 0 10 10A10.011 10.011 0 0 0 10 0Zm3.982 13.982a6.938 6.938 0 0 1-7.964 0A3.997 3.997 0 0 1 10 11a3.997 3.997 0 0 1 3.982 2.982ZM13.5 5.5a3.5 3.5 0 1 1-7 0 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5 a3.5"/>
                    </svg>
                    <span class="text-xs mt-1">{move || format!("Round {}", current_round.get())}</span>
                </button>
            </div>
        </div>
    }
}